@@ -25,7 +25,7 @@ import click
 from bump_release import helpers
 
 # region Globals
-__version__ = VERSION = "0.10.2"
+__version__ = VERSION = "0.10.3"
 RELEASE_FILE: Optional[Path] = None
 RELEASE_CONFIG: Optional[ConfigParser] = None
 
@@ -153,7 +153,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
     try:
         new_row = update_setup_cfg_file(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
-            logging.debug(f"process_update() `setup`: new_row = {new_row.strip()}")
+            logging.debug(f"process_update() `setup_cfg`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
         logging.warning(f"process_update() No release section for `setup`: {e}")
     # endregion Update setup.cfg file
@@ -384,7 +384,7 @@ def update_ansible_vars(version: helpers.VersionNumber, base_path: Path, dry_run
         logging.debug(f"update_ansible_vars() path = {path}")
         key = RELEASE_CONFIG.get("ansible", "key", fallback=helpers.ANSIBLE_KEY)  # noqa
     except configparser.Error as e:
-        raise helpers.NothingToDoException("No action to perform for ansible file", e)
+        raise helpers.NothingToDoException("No action to perform for `ansible` file", e)
     return helpers.updates_yaml_file(path=path, version=version, key=key, dry_run=dry_run)
 
 
