@@ -194,7 +194,7 @@ def update_json_file(
                 package_file.write(updated)
         return updated
     except IOError as ioe:
-        raise UpdateException(f"update_json_file() Unable to perform {package_file} update: {ioe}")
+        raise UpdateException(f"update_json_file() Unable to perform `package_file` update: {ioe}")
 
 
 class MyYAML(YAML):
